@@ -6,7 +6,7 @@ from typing import Callable, Union
 from dataclasses import asdict
 
 from ..structs import Method, State, DeviceProfile, IGProfile
-from .structs.post import PostPost, PostComment, PostUpdateCaption, PostSave, PostLike, PostUnlike, PostPostDevice
+from .structs.post import PostPost, PostComment, PostUpdateCaption, PostSave, PostLike, PostUnlike, PostPostDevice, PostRetrieveByUser
 
 from .helpers import build_default_rupload_params
 
@@ -29,13 +29,15 @@ class PostMixin:
         obj._csrftoken = self._session.cookies['csrftoken']
         obj._uid = self.state.user_id
         obj._uuid = self.state.uuid
+        if obj.feed_position is None:
+            delattr(obj, 'feed_position')
 
         endpoint = f'media/{obj.media_id}/{obj.action}/'
         return self._request(endpoint, Method.POST, data=obj.__dict__, signed=True)
 
     def post_like(self, obj: PostLike) -> Response:
         """Likes a post"""
-        return self._request(obj)
+        return self._post_act(obj)
 
     def post_unlike(self, obj: PostUnlike) -> Response:
         """Unlikes a post"""
@@ -109,3 +111,28 @@ class PostMixin:
             'retry_context': json.dumps({"num_reupload": 0, "num_step_auto_retry": 0, "num_step_manual_retry": 0})
         }
         return self._request('media/configure/', Method.POST, data=as_dict, headers=headers, signed=True)
+
+    def post_retrieve_by_user(self, obj: PostRetrieveByUser) -> (PostRetrieveByUser, Union[dict, bool]):
+        """Retrieves 12 posts of the user at a time. If there was a response / if there were any more posts
+        available, the response can be found in original_requests/post.json:4
+
+        Returns
+        --------
+        PostRetrieveByUser, (dict, bool)
+            Will return the updated object and the response if there were any posts left, returns the object and
+            False if not.
+        """
+        as_dict = obj.__dict__.copy()
+
+        if obj.page > 0 and obj.max_id is None:
+            return obj, False
+
+        as_dict.pop('max_id')
+        as_dict.pop('user_id')
+
+        resp = self._request(f'feed/user/{obj.user_id}/', Method.GET, query=as_dict)
+        resp_as_json = resp.json()
+
+        obj.max_id = resp_as_json['next_max_id']
+        obj.page += 1
+        return obj, resp_as_json['items']
