@@ -3,6 +3,7 @@ import random
 import time
 import imagesize
 import logging
+import pprint
 import json
 
 from pathlib import Path
@@ -26,6 +27,7 @@ class _PostBase:
     is_carousel_bumped_post: str = 'False'
     container_module: str = None
     media_id: str = None
+    feed_position: str = None
 
     def _create(self, **kwargs):
         """Creates an instance of the class, this method should be overwritten in the individual classes with
@@ -41,6 +43,9 @@ class _PostBase:
             else:
                 logger.warning("{} was sent as a keyword argument, but isn't supported.")
 
+    def __repr__(self):
+        return pprint.pformat(self.__dict__)
+
 
 @dataclass
 class PostUnlike(_PostBase):
@@ -60,6 +65,10 @@ class PostUnlike(_PostBase):
         -------
         PostUnlike
             The newly instantiated class instance.
+        Other Parameters
+        -------
+        feed_position : str
+            Specifies which post from the feed it is, starts at 0.
         """
         i = cls()
         i._create(media_id=media_id, **kwargs)
@@ -83,6 +92,10 @@ class PostLike(_PostBase):
         -------
         PostLike
             The newly instantiated class instance.
+        Other Parameters
+        -------
+        feed_position : str
+            Specifies which post from the feed it is, starts at 0.
         """
         i = cls()
         i._create(media_id=media_id, **kwargs)
@@ -106,6 +119,10 @@ class PostSave(_PostBase):
         -------
         PostSave
             The newly instantiated class instance.
+        Other Parameters
+        -------
+        feed_position : str
+            Specifies which post from the feed it is, starts at 0.
         """
         i = cls()
         i._create(media_id=media_id, **kwargs)
@@ -134,6 +151,10 @@ class PostComment(_PostBase):
         -------
         PostComment
             The newly instantiated class instance.
+        Other Parameters
+        -------
+        feed_position : str
+            Specifies which post from the feed it is, starts at 0.
         """
         i = cls()
         i._create(media_id=media_id, comment_text=comment_text, **kwargs)
@@ -162,6 +183,10 @@ class PostUpdateCaption(_PostBase):
         -------
         PostUpdateCaption
             The newly instantiated class instance.
+        Other Parameters
+        -------
+        feed_position : str
+            Specifies which post from the feed it is, starts at 0.
         """
         i = cls()
         i._create(media_id=media_id, caption_text=caption_text, **kwargs)
@@ -179,6 +204,9 @@ class PostPostLocation:
     facebook_places: str = ""
     facebook_places_id: str = ""
 
+    def __repr__(self):
+        return pprint.pformat(self.__dict__)
+
 
 @dataclass
 class PostPostDevice:
@@ -189,6 +217,9 @@ class PostPostDevice:
     android_version: int
     android_release: str
 
+    def __repr__(self):
+        return pprint.pformat(self.__dict__)
+
 
 @dataclass
 class PostPostEdits:
@@ -197,6 +228,9 @@ class PostPostEdits:
     crop_center: List[float] = field(default_factory=lambda: [0.0, 0.0])
     crop_zoom: float = 1.0
 
+    def __repr__(self):
+        return pprint.pformat(self.__dict__)
+
 
 @dataclass
 class PostPostExtra:
@@ -204,6 +238,9 @@ class PostPostExtra:
     source_width: int
     source_height: int
 
+    def __repr__(self):
+        return pprint.pformat(self.__dict__)
+
 
 @dataclass
 class PostPost(_PostBase):
@@ -248,7 +285,7 @@ class PostPost(_PostBase):
         extra
         Returns
         -------
-        PostUpdateCaption
+        PostPost
             The newly instantiated class instance.
         """
         source_type = str(source_type)
@@ -291,3 +328,36 @@ class PostPost(_PostBase):
             setattr(instance, k, v)
 
         return instance
+
+
+@dataclass
+class PostRetrieveByUser:
+    user_id: str = None
+    max_id: str = None
+    exclude_comment: str = 'true'
+    only_fetch_first_carousel_media: str = 'false'
+    page = 0
+
+    @classmethod
+    def create(cls, user_id: str, **kwargs) -> "PostRetrieveByUser":
+        """
+        Parameters
+        ----------
+        user_id : str
+        Other Parameters
+        ----------
+        exclude_comment : str
+            'true' will only retrieve the posts, 'false' will retrieve the posts + top comments
+        only_fetch_first_carousel_media : str
+            'true' will retrieve only the first post, if it's a carousel post (multiple images / videos),
+            'false' will return all media.
+        """
+        i = cls()
+        i.user_id = user_id
+        for k, v in kwargs.items():
+            if hasattr(i, k):
+                setattr(i, k, v)
+        return i
+
+    def __repr__(self):
+        return pprint.pformat(self.__dict__)
